==> v2.0.tar.gz: daw/footer-home.php <==
<div class="container-fluid footer footer-home dark">
	<div class="container">
		<div class="row">
			<div class="col-md-4">
				<ul style="float:left;margin-right:10px;">
					<li><a href="<?php echo home_url( '/' ); ?>about"><span class="fa fa-file-text-o fa-fw"></span> About</a></li>
					<li><a href="http://photo.davidawindham.com" title="Photo" ><span class="fa fa-camera-retro fa-fw"></span> Photo</a></li>
					<li><a href="http://radio.davidawindham.com"><span class="fa fa-microphone fa-fw"></span> Radio</a></li>
					<li><a href="http://chess.davidawindham.com">&#9814; Chess</a></li>

				</ul>
				<ul style="float:left;margin-right:10px;">
					<li><a href="<?php echo home_url( '/' ); ?>desk"><span class="fa fa-pencil-square-o fa-fw"></span> Desk</a></li>
					<li><a href="<?php echo home_url( '/' ); ?>studio/art/" title="Art" ><span class="fa fa-paint-brush fa-fw"></span> Paint</a>
					<li><a href="http://code.davidawindham.com"><span class="fa fa-code fa-fw"></span> Code</a></li>
					<li><a href="<?php echo home_url( '/' ); ?>shop"><span class="fa fa-credit-card fa-fw"></span> Shop</a></li>
					

				</ul>
				<ul>		
					<li><a href="<?php echo home_url( '/' ); ?>studio"><span class="fa fa-flask fa-fw"></span> Studio</a></li>
					<li><a href="<?php echo home_url( '/' ); ?>contact"><span class="fa fa-envelope-o fa-fw"></span> Contact</a></li>
					<li><a href="http://chat.davidawindham.com"><span class="fa fa-comment fa-fw"></span> Chat</a></li>
					<li><a href="<?php echo home_url( '/' ); ?>about/analytics/" title="analytics" ><span class="fa fa-tachometer fa-fw"></span> Stats</a></li>
				</ul>
			</div>
		</div>
		<div class="row">
			<div class="col-md-4">
				<ul class="social">			
					<li><a href="https://twitter.com/windhamdavid" class="twitter" rel="me"><span class="fa fa-2x fa-twitter-square"></span></a></li>
					<li><a href="https://www.facebook.com/davidawindham" class="facebook"><span class="fa fa-2x fa-facebook-square"></span></a></li>
					<li><a href="https://github.com/windhamdavid" class="github" rel="me"><span class="fa fa-2x fa-github-square"></span></a></li>
				</ul>
			</div>
			<div class="col-md-3 col-sm-offset-5">
				<p class="small dim right">&copy; 2004-2020<br />
				<p class="small dim right"><a href="<?php echo home_url( '/' ); ?>sitemap"><span class="fa fa-sitemap fa-fw"></span> Sitemap</a><br />
				<span class="small dull right">This website uses cookies</span></p>
			</div>
		</div>
	</div>
</div>
<?php wp_footer(); ?>
</body>
</html>

==> v4.0.tar.gz: daw/footer-home.php <==
<div class="container-fluid footer footer-home dark">
	<div class="container">
		<div class="row">
			<div class="col-md-4">
				<ul style="float:left;margin-right:10px;">
					<li><a href="<?php echo home_url( '/' ); ?>about"><span class="fa fa-file-text-o fa-fw"></span> About</a></li>
					<li><a href="http://photo.davidwindham.com" title="Photo" ><span class="fa fa-camera-retro fa-fw"></span> Photo</a></li>
					<li><a href="http://radio.davidawindham.com"><span class="fa fa-microphone fa-fw"></span> Radio</a></li>
					<li><a href="http://chess.davidwindham.com"><span class="chess-html">&#9814;</span> Chess</a></li>
				</ul>
				<ul style="float:left;margin-right:10px;">
					<li><a href="<?php echo home_url( '/' ); ?>desk"><span class="fa fa-pencil-square-o fa-fw"></span> Desk</a></li>
					<li><a href="<?php echo home_url( '/' ); ?>studio/art/" title="Art" ><span class="fa fa-paint-brush fa-fw"></span> Paint</a>
					<li><a href="http://code.davidawindham.com"><span class="fa fa-code fa-fw"></span> Code</a></li>
					<li><a href="<?php echo home_url( '/' ); ?>shop"><span class="fa fa-credit-card fa-fw"></span> Shop</a></li>
				</ul>
				<ul>
					<li><a href="<?php echo home_url( '/' ); ?>studio"><span class="fa fa-flask fa-fw"></span> Studio</a></li>
					<li><a href="<?php echo home_url( '/' ); ?>contact"><span class="fa fa-envelope-o fa-fw"></span> Contact</a></li>
					<li><a href="https://davidwindham.com/rtc"><span class="fa fa-comment fa-fw"></span> Chat</a></li>
					<li><a href="<?php echo home_url( '/' ); ?>about/analytics/" title="analytics" ><span class="fa fa-tachometer fa-fw"></span> Stats</a></li>
				</ul>
			</div>
		</div>
		<div class="row mt-5">
			<div class="col-md-4">
				<ul class="social">
					<li><a href="https://twitter.com/windhamdavid" class="twitter" rel="me"><span class="fa fa-2x fa-twitter-square"></span></a></li>
					<li><a href="https://www.facebook.com/davidawindham" class="facebook"><span class="fa fa-2x fa-facebook-square"></span></a></li>
          <li><a href="https://www.reddit.com/user/windhamdavid" class="reddit"><span class="fa fa-2x fa-reddit-square"></span></a></li>
					<li><a href="https://github.com/windhamdavid" class="github" rel="me"><span class="fa fa-2x fa-github-square"></span></a></li>
				</ul>
			</div>
			<div class="col-md-3 offset-sm-5">
				<p class="small dim right">&copy; 2004-2022<br />
				<p class="small dim right"><a href="<?php echo home_url( '/' ); ?>sitemap"><span class="fa fa-sitemap fa-fw"></span> Sitemap</a><br />
				<span class="small dull right">This website uses cookies</span></p>
			</div>
		</div>
	</div>
	<div class="cookie-notification js-cookie-notification">
		<p>By using this website, you agree to the use of<br />cookies and the <a href="https://davidawindham.com/privacy/">privacy policy</a>.</p>
		<button class="btn btn-default" type="submit"><a href="#" class="js-cookie-notification-hide">Agree and dismiss</a></button>
	</div>
</div>
<?php wp_footer(); ?>
</body>
</html>
